@@ -2,11 +2,13 @@
 
 __author__ = """Kaushik Muduchuru"""
 __email__ = "kaushik.reddy.m@gmail.com"
-__version__ = "0.0.6"
+__version__ = "0.1.2"
 
 from .utils.utils_download import * # etc.
 from .utils.config import load_config
 from .datasets.DWD import DWDmirror as DWD
 from .datasets.MSWX import MSWXmirror as MSWX
 from .datasets.ERA5 import ERA5Mirror as ERA5
+from .datasets.CMIPlocal import CMIPmirror as CMIPlocal
+from .datasets.CMIPCloud import CMIPCloud as CMIP
 
